import { reactive, onMounted, ref, ElMessage, ElMessageBox, http, getGroupUrl, RegularVerification, verification, PaginationProps } from "@/utils/importUsed";
import { useRoute } from "vue-router";
// 表单实例
const ruleFormRef = ref()
export function usePriRecursionStartField() {
  // 接口列表实例
  let UrlList = reactive(null)
  // 获取当前板块接口列表
  onMounted(async () => {
    const route = useRoute();
    form.objectTableId = Number(route.query.objectTableId);

    UrlList = await getGroupUrl(["prizeSet"]);
    onSearch(ruleFormRef.value);
    objectTableIdQuery();

  });
  let form = reactive({
    fieldName: "", //字段名称
    fieldEnName: "", //字段名
    objectTableId: null, //对象表


  });
  const dataList = ref([]);
  const loading = ref(false);
  const dialogAddVisible = ref(false);
  const pagination = reactive<PaginationProps>({
    total: 0,
    pageSize: 10,
    currentPage: 1,
    background: true
  });
  const columns: TableColumnList = [
    {
      type: "selection",
      width: 55,
      align: "left",
      hide: ({ checkList }) => !checkList.includes("勾选列")
    },
    {
      label: "序号",
      type: "index",
      width: 70,
      hide: ({ checkList }) => !checkList.includes("序号列")
    },
    {
      label: "ID",
      prop: "id",
      minWidth: 200
    },
    {
      label: "字段名称",
      prop: "fieldName",
      minWidth: 200
    },
    {
      label: "字段名",
      prop: "fieldEnName",
      minWidth: 200
    },
    {
      label: "匹配条件",
      prop: "fieldQueryKind",
      minWidth: 200
    },
    {
      label: "匹配方式",
      prop: "fieldQueryModel",
      minWidth: 200
    },
    {
      label: "匹配值",
      prop: "fieldQueryValue",
      minWidth: 200
    },
    {
      label: "匹配值类型",
      prop: "fieldQueryValueType",
      minWidth: 200
    },
    {
      label: "对象表",
      prop: "objectTableId",
      minWidth: 200
    },

    {
      label: "操作",
      fixed: "right",
      width: 200,
      slot: "operation"
    }
  ];
  // 当前页数量切换
  function handleSizeChange(val: number) {
    if (typeof val === "number") {
      pagination.pageSize = val;
      onSearch(ruleFormRef.value);
    }
  }
  // 当前页码切换
  function handleCurrentChange(val: number) {
    console.log(`current page: ${val}`);
    if (typeof val === "number") {
      pagination.currentPage = val;
      onSearch(ruleFormRef.value);
    }
  }
  // 选择表格项
  function handleSelectionChange(val) {
    console.log(`SelectionChange: ${val}`);
    onSearch(ruleFormRef.value);
  }
  // 搜索列表
  async function onSearch(formEl) {
    // 表单校验拦截
    if (!formEl) return
    await formEl.validate(async (valid, fields) => {
      if (valid) {
        //表单校验成功回调
        console.log('submit!')
        // 状态调整为加载中
        loading.value = true;
        // 调用接口（需动态生成接口）
        const { status, msg, data }: any = await http.Request({
          method: UrlList.prizeSet.prigetPriRecursionStartFieldList.method,
          url: UrlList.prizeSet.prigetPriRecursionStartFieldList.url,
          params: {
            ...form,
            pageSize: pagination.pageSize,
            pageNum: pagination.currentPage
          }
        });
        dataList.value = data.records;
        pagination.total = data.total;
        setTimeout(() => {
          loading.value = false;
        }, 500);
      } else {
        //表单校验失败回调
        ElMessage({
          message: "请输入完整信息",
          type: "error"
        });
      }
    })
  }
  // 对象表选项数据
  const objectTableIdOptionList = ref([]);
  //获取对象表数据
  async function objectTableIdQuery() {
    const { status, data }: any = await http.Request({ method: UrlList.prizeSet.prigetPriRecursionStartTableDic.method, url: UrlList.prizeSet.prigetPriRecursionStartTableDic.url, params: {} });
    if (status === 1) {
      objectTableIdOptionList.value = data.records;
    }
  }




  // 删除
  function handleDelete(row) {
    ElMessageBox.confirm(
      `是否删除该递归开始条件字段? `,
      "提示",
      {
        confirmButtonText: "删除",
        cancelButtonText: "取消",
        type: "warning"
      }
    ).then(async () => {
      const { status, msg }: any = await http.Request({ method: UrlList.prizeSet.prideletePriRecursionStartField.method, url: UrlList.prizeSet.prideletePriRecursionStartField.url, params: String(row.id) });
      if (status === 1) {
        ElMessage({
          message: "删除成功",
          type: "success"
        });
        onSearch(ruleFormRef.value);
      } else {
        ElMessageBox.alert(msg, "提示", {
          confirmButtonText: "关闭",
          type: "warning"
        });
      };
    })
  }

  // 新增
  const addVisible = ref(false);
  function handleAdd() {
    addVisible.value = true;
  };

  // 修改
  const editUpdatePriRecursionStartFieldVisible = ref(false);
  const editUpdatePriRecursionStartFieldFormData = ref({});
  function handleUpdatePriRecursionStartField(row) {
    editUpdatePriRecursionStartFieldVisible.value = true;
    // 表格数据赋值
    editUpdatePriRecursionStartFieldFormData.value = row;
  };

  return {
    form,
    loading,
    columns,
    dataList,
    pagination,
    onSearch,
    handleSizeChange,
    handleCurrentChange,
    handleSelectionChange,
    ruleFormRef,
    objectTableIdQuery,
    objectTableIdOptionList,

    handleAdd,
    addVisible,
    handleUpdatePriRecursionStartField,
    editUpdatePriRecursionStartFieldVisible,
    editUpdatePriRecursionStartFieldFormData,
    handleDelete,

  };
}
